
/*                       SCL1.LIB's Sound & Time Functions Demo

	To run this demo inside QuickC environment:

		Copy SCL1.H into your INCLUDE subdirectory.
		Load SCL1 Quick Library.
		Turn Screen Swapping On (QC's Debug Menu).
		Compile it (memory output option and debug option on if you
					want to step through).


		To Load SCL1 Quick Library:

			qc /l scl1

	File SCL1.QLB must be located in the path specified in the LIB
	environment variable directory or in your default drive/path   */

#include <scl1.h>
#include <stdlib.h>

char s[80]="SCL1's Sound & Time Demo has been active for ";

char *Day[]={"Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"};

char *Month[]={"","January","February","March","April","May","June","July",
				"August","September","October","November","December"};

main()
{
int i,frequency,minutes,seconds;
struct DateData *p;
char Buffer[40];

/* Turn Stopwatch ON to count program execution time */

StopWatch(SW_START);

/* Clear Screen and turn cursor off */

Cls(7,CLS_ALL);
CursorOff();
WriteScreen(7,0,20,"<< SCL1's Time & Sound Functions Demo >>");

/* Write date and time to screen top row. GetTime returns a pointer to a
   buffer with the time in ASCII */


WriteScreen(7,3,3,"Time:");
WriteScreen(7,4,0,"Seconds:");
WriteScreen(7,3,9,GetTime());

/* Write today's date using GetDate. This functions returns a pointer to
   structure DateData defined in SCL1.H. */

p=GetDate();

/* p points to DateData structure: p->WeekDay = day of the week (0=Sunday),
	p->MonthDay = day (1-31), p->Month = month (1-12)
	p->Year = year (1980 - 2099).

	The month and day numbers reported by GetDate will be used as index
	to the week and months names arrays we have previously defined.

	Use sprintf to get a string out of this data */

sprintf(Buffer,"Today is %s, %s %d, %d",Day[p->WeekDay],Month[p->Month],p->MonthDay,p->Year);

WriteScreen(7,2,1,Buffer);

/* Use function WaitTime to wait 100 hundreths of a second. A point will
   be written to the screen after each elapsed second and time updated
   Parameters: Time to wait in hundreths of seconds */

for(i=0;i<11;++i)
	{
	WaitTime(100);                  /* Wait one second */
	WriteChar(7,4,i+9,1,'.');         /* Write a point */
	WriteScreen(7,3,9,GetTime());   /* Update time */
	}

Cls(7,4,0,4,20);           /* Erase points */

/* Use Sound to set timer to a desired frequency.
   Parameters: Frequency in Hertz */

Sound(200);

/* Turn Sound On */

SoundOn();

/* Change frequency every 2/100 of a second  */

for(i=0,frequency=220;i<40;++i,frequency+=20)
	{
	Sound(frequency);                    /* Change frequency */
	WaitTime(2);                    /* Wait 2/100 of a second */
	WriteChar(7,4,i,1,'.');         /* Write a point */
	WriteScreen(7,3,9,GetTime());   /* Update time */
	}

/* Turn sound off */

SoundOff();

/* You can also use TSound to produce sounds.
   Parameters: Frequency in Hertz, time in hundreths of seconds
   Musical notes frequencies has been defined in SCL1.H. For example
   TS_G4 means Natural G, octave 4, TS_Ef4 means E flat octave 4,
   TS_As3 means A sharp octave 3*/


Cls(7,4,0,4,40);           /* Erase points */

WriteScreen(7,3,9,GetTime());   /* Update time */

WaitTime(100);

for(i=0;i<3;++i)
	TSound(TS_G4,20);
TSound(TS_Ef4,40);

WriteScreen(7,3,9,GetTime());   /* Update time */

/* Restore cursor */

SetCurPos(10,0);
CursorOn();

/* Calculate demo execution time. Stopwatch returns a long with elapsed
   time since it was first called in hundreths of seconds */

i=StopWatch(SW_STOP);

minutes=i/6000;
seconds=(i%6000)/100;

/* if minutes > 0 write minutes */

if(minutes)
	sprintf(&s[45],"%d minute(s) and %d seconds",minutes,seconds);

/* else write only seconds */

else
	sprintf(&s[45],"%d seconds",seconds);
WriteScreen(0x0f,6,0,s);
}


